[前][次][番号順一覧][スレッド一覧]

ruby-changes:36510

From: tarui <ko1@a...>
Date: Wed, 26 Nov 2014 22:31:29 +0900 (JST)
Subject: [ruby-changes:36510] tarui:r48592 (trunk): * test/ruby/test_autoload.rb (class TestAutoload): change load target

tarui	2014-11-26 22:31:23 +0900 (Wed, 26 Nov 2014)

  New Revision: 48592

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=48592

  Log:
    * test/ruby/test_autoload.rb (class TestAutoload): change load target
      from Continuation to Date. Becouse Continuation is no longer quiet.

  Modified files:
    trunk/test/ruby/test_autoload.rb
Index: test/ruby/test_autoload.rb
===================================================================
--- test/ruby/test_autoload.rb	(revision 48591)
+++ test/ruby/test_autoload.rb	(revision 48592)
@@ -4,10 +4,10 @@ require 'thread' https://github.com/ruby/ruby/blob/trunk/test/ruby/test_autoload.rb#L4
 
 class TestAutoload < Test::Unit::TestCase
   def test_autoload_so
     # Continuation is always available, unless excluded intentionally.
     assert_in_out_err([], <<-INPUT, [], [])
-    autoload :Continuation, "continuation"
-    begin Continuation; rescue LoadError; end
+    autoload :Date, "date"
+    begin Date; rescue LoadError; end
     INPUT
   end
 
@@ -4,10 +4,10 @@ require 'thread' https://github.com/ruby/ruby/blob/trunk/test/ruby/test_autoload.rb#L4
 class TestAutoload < Test::Unit::TestCase
   def test_autoload_so
-    # Continuation is always available, unless excluded intentionally.
+    # Date is always available, unless excluded intentionally.
     assert_in_out_err([], <<-INPUT, [], [])

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]